==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/fi.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Hallitse Lightbox Gallary parametrit");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Hallitse Galleria");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image leveys");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Korkeus");
define('MANAGE_GALLERY_THUMB_WIDTH', "Näytekuva leveys");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Näytekuva Korkeus");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Säilytä Peukalo Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Nimikkeet");
define('MANAGE_GALLERY_DISABLE_SORT', "Poista Lajittelu");
define('MANAGE_GALLERY_DELETE_IMAGE', "kuvan poistaminen");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Tallenna Lajittelu Tilaa");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klikkaa &quot;Update&quot; julkaista <br /> lataamiasi kuvia.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Kaikki kuvat ovat kokoa ja asetukset on tallennettu.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Virhe koon kuvia tai tallentamatta asetuksia.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Kuvasi (t) on ladattu.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Virhe lataamisessa kuva (t).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Tiedosto yrität ladata ei ole kuva.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Tiedosto jota yrität siirtää on liian suuri.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Otsikon on tallennettu.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Oletko varma, että haluat poistaa kuvan");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Kuva on poistettu.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Virhe poistettaessa kuvaa.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Tallentaminen parametrit ja koon kuvat, odota ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Lataaminen, odota ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Järjestys ei ole tallennettu. Haluatko tallentaa lajittelujärjestyksen?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Kuva lajittelujärjestys on tallennettu.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Tapahtui virhe tallennettaessa kuvaa lajitella.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/fi.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Hallitse Lightbox Gallary parametrit");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Hallitse Galleria");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image leveys");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Korkeus");
define('MANAGE_GALLERY_THUMB_WIDTH', "Näytekuva leveys");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Näytekuva Korkeus");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Säilytä Peukalo Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Nimikkeet");
define('MANAGE_GALLERY_DISABLE_SORT', "Poista Lajittelu");
define('MANAGE_GALLERY_DELETE_IMAGE', "kuvan poistaminen");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Tallenna Lajittelu Tilaa");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klikkaa &quot;Update&quot; julkaista <br /> lataamiasi kuvia.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Kaikki kuvat ovat kokoa ja asetukset on tallennettu.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Virhe koon kuvia tai tallentamatta asetuksia.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Kuvasi (t) on ladattu.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Virhe lataamisessa kuva (t).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Tiedosto yrität ladata ei ole kuva.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Tiedosto jota yrität siirtää on liian suuri.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Otsikon on tallennettu.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Oletko varma, että haluat poistaa kuvan");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Kuva on poistettu.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Virhe poistettaessa kuvaa.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Tallentaminen parametrit ja koon kuvat, odota ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Lataaminen, odota ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Järjestys ei ole tallennettu. Haluatko tallentaa lajittelujärjestyksen?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Kuva lajittelujärjestys on tallennettu.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Tapahtui virhe tallennettaessa kuvaa lajitella.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Tiedosto, jota yrität ladata, on suurempi kuin &#39;upload_max_filesize&#39; tai &#39;post_max_size&#39; PHP-asetukset. Ota yhteyttä järjestelmänvalvojaan lisätäksesi näitä rajoituksia.");
?>
